Package: pogos
Title: PharmacOGenomics Ontology Support
Description: Provide simple utilities for querying bhklab PharmacoDB, modeling 
	API outputs, and integrating to cell and compound ontologies.
Version: 1.33.0
Author: Vince Carey <stvjc@channing.harvard.edu>
Suggests: knitr, DT, ontologyPlot, testthat, rmarkdown, BiocStyle
Imports: methods, S4Vectors, utils, shiny, ontoProc, ggplot2, graphics
Depends: R (>= 3.5.0), rjson (>= 0.2.15), httr (>= 1.3.1)
Maintainer: VJ Carey <stvjc@channing.harvard.edu>
License: Artistic-2.0
LazyLoad: yes
LazyData: yes
biocViews: Pharmacogenomics, PooledScreens, ImmunoOncology
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/pogos
git_branch: devel
git_last_commit: b30e578
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 23:36:46 UTC; biocbuild
