# Generated by roxygen2: do not edit by hand

export(DRProfSet)
export(DRTraceSet)
export(basicDecoder)
export(compoundsByCell)
export(getDrugs)
export(iriCCLE)
export(rxdbQuery_v1)
export(topEndpoints_v1)
export(traces)
exportClasses(DRProfile)
exportClasses(DRTraceSet)
exportMethods("[")
exportMethods(plot)
import(ggplot2)
import(httr)
import(methods)
import(ontoProc)
import(rjson)
import(shiny)
importFrom(S4Vectors,DataFrame)
importFrom(graphics,lines)
importFrom(methods,is)
importFrom(utils,data)
