#' compounds_v1: serialization of compounds info from PharmacoDb v1
#' @importFrom utils data
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(compounds_v1)
#' head(compounds_v1)
"compounds_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(tissues_v1)
#' head(tissues_v1)
"tissues_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(cell_lines_v1)
#' head(cell_lines_v1)
"cell_lines_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(datasets_v1)
#' head(datasets_v1)
"datasets_v1"

#' @rdname compounds_v1
#' @docType data
#' @format DRTraceSet instance
#' @source PharmacoDb April 2018
#' @examples
#' data(CCLE_drts)
#' CCLE_drts
"CCLE_drts"
