% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rxdbHandling.R
\name{rxdbQuery_v1}
\alias{rxdbQuery_v1}
\title{very simple query formulation, build queries using endpoints of bhklab PharmacoDB API}
\usage{
rxdbQuery_v1(
  ...,
  url = "https://pharmacodb.pmgenomics.ca/api/v1/",
  decoder = basicDecoder
)
}
\arguments{
\item{\dots}{typically a string representing an API endpoint, will be processed by unlist() and then to paste0 preceded by \code{url}}

\item{url}{of a PharmacoDB server API target}

\item{decoder}{a function of one argument that will be applied to API response (typically JSON)}
}
\value{
typically a list, dependent on decoder parameter
}
\description{
very simple query formulation, build queries using endpoints of bhklab PharmacoDB API
}
\examples{
qout = try(rxdbQuery_v1('cell_lines')) # yields 30; append '?all=true' to retrieve all
if (!inherits(qout, "try-error")) unlist(lapply(qout, function(x) x[[2]]))
# or pmgenomics.ca is down
}
