% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lkcomb.R
\name{traces}
\alias{traces}
\title{trace extractor}
\usage{
traces(x)
}
\arguments{
\item{x}{instance of DRTraceSet}
}
\value{
a list of DRProfile instances
}
\description{
trace extractor
}
\examples{
iri = iriCCLE()
str(traces(iri)[[1]])
}
